/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitCBShape.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2007 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single CBShape distribution (Crystal Ball).

#include "AFit/AFitCBShape.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooCBShape.hh"
#else
#include "RooCBShape.h"
#endif

ClassImp(AFitCBShape)
  ;

AFitCBShape::AFitCBShape(RooAbsReal& x, TString name)
  : mean(name+"mean", "Mean of CBShape", 0.0, -10.0, 10.0)
    , width(name+"width", "Width of CBShape", 1.0, 0.0, 10.0)
    , alpha(name+"alpha", "alpha parameter of CB shape", 1.0, 0.0, 10.0)
    , n(name+"n", "power tail parameter of CB shape", 1.0, 0.0, 10.0)
 {
  // Constructor
  _name     = name;

  _x = &x;

  const RooArgSet * argVarSet = _x->getVariables();
  if(argVarSet->getSize() == 1) {
    TIterator * iter = argVarSet->createIterator();
    RooRealVar * var = (RooRealVar*)iter->Next();
    if(var){
      mean.setRange(var->getMin(), var->getMax());
      width.setRange(0.0,  var->getMax()-var->getMin());
    }
  }

  varSet.add(mean);
  varSet.add(width);
  varSet.add(alpha);
  varSet.add(n);

  readDataCard();
}

void AFitCBShape::buildPdf() {
  // Build the Pdf
    _thePdf = new RooCBShape(_name, "CBShape PDF", *_x, mean, width, alpha, n);
}

