/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitGeneric.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a generic PDF with a functional form y=f(x)

#include "AFit/AFitGeneric.hh"
#ifdef __BABARROOFIT__
// RooFit includes
#include "RooFitCore/RooGenericPdf.hh"
#else
// RooFit includes
#include "RooGenericPdf.h"
#endif

ClassImp(AFitGeneric)
  ;

AFitGeneric::AFitGeneric(RooAbsReal& x, TString name, TString formula)
  : _formulaStrVar(name+"_formula", "Functional for of f(x)", formula)
 {
  // Constructor
  _name = name;

  _x = &x;

  // the default functional form of the formula is f(x) = x.  In order to 
  // change the functional form one should modify the value of the string 
  // _formulaStrVar which is read from the configuration file.
  varSet.addOwned( _formulaStrVar );

  readDataCard();

}

void AFitGeneric::buildPdf() {
  cout << "buildPdf function" << endl;
  _thePdf = new RooGenericPdf(_name, "Generic Formula PDF: f(x)", _formulaStrVar.getVal(), RooArgList(*_x));
  cout << "now have pdf - " << _thePdf << endl;
}

