/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitHist.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2007 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFit] --
// This class builds a single histogram PDF distribution

#include "AFit/AFitHist.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooHistPdf.hh"
#else
#include "RooHistPdf.h"
#endif

ClassImp(AFitHist)
  ;

AFitHist::AFitHist(RooAbsReal& x, TString name)
  : datafile(name+"_file", "File name", "null"),
    histname(name+"_hist", "Histogram name", "null"),
    order(name+"_order", "Interpolation order", 0)
 {
  // Constructor
  _name     = name;

  _x = &x;

  varSet.add(datafile);
  varSet.add(histname);
  varSet.add(order);

  readDataCard();
}

AFitHist::~AFitHist() {
  delete datahist;
}

void AFitHist::buildPdf() {
  // Build the Pdf
  TFile f( datafile.getVal() );
  hist = (TH1*)f.Get(histname.getVal());
  if(!hist) {
    cout << ClassName() << "::ERROR - unable to get histogram " << histname.getVal() << " from file " << datafile.getVal() << "." << endl;
    assert(0);
  }

  datahist = new RooDataHist(_name + "_datahist", "Data hist",  RooArgList(*_x), hist);
  _thePdf = new RooHistPdf(_name, "Histogram PDF", RooArgSet(*_x), *datahist, (Int_t)order.getVal());
}

