/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitParametricStepFunction.cc,v 1.5 2005/07/03 23:04:22 bevan Exp $
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [AFitParametricStepFunction] --
// This class builds a single ParametricStepFunction distribution

#include "AFit/AFitParametricStepFunction.hh"
#ifdef __BABARROOFIT__
#include "RooFitModels/RooParametricStepFunction.hh"
#else
#include "RooParametricStepFunction.h"
#endif

ClassImp(AFitParametricStepFunction)
  ;

AFitParametricStepFunction::AFitParametricStepFunction(RooAbsReal& x, TString name)
  : nBins(name+"_nbins", "Number of Bins for a Parametric Step Function", 2, 1.0, 10.0)
 {
  // Constructor
  _name     = name;

  _x = &x;

  varSet.addOwned(nBins);
  readDataCard();
 
  for(int i=0; i < (int)nBins.getVal(); i++) {
    TString thisVar = name;
    thisVar += "_PSFcoef_";
    thisVar += long(i);
    thisVar.ReplaceAll(" ", "");
    RooRealVar * newVar = new RooRealVar( thisVar , "Parametric Step Function Coefficient " +long(i), 0.0);
    varSet.addOwned(*newVar);
  }

  // We need to have N+1 bin limits to create N bins
  for(int i=0; i <= (int)nBins.getVal(); i++) {
    TString thisLimit = name;
    thisLimit += "_PSFlimit_";
    thisLimit += long(i);
    thisLimit.ReplaceAll(" ", "");
    RooRealVar * newVarLimit = new RooRealVar( thisLimit , "Parametric Step Function Bin Limit " +long(i),0.0);

    varSet.addOwned(*newVarLimit);

    coefList.addOwned(*newVarLimit);
  }

  readDataCard();

  limits.Set((Int_t)nBins.getVal() + 1);

  for(int i=0; i <= (int)nBins.getVal(); i++) {
    TString thisLimit = name;
    thisLimit += "_PSFlimit_";
    thisLimit += long(i);
    thisLimit.ReplaceAll(" ", "");
    RooRealVar * rrv = (RooRealVar*)varSet.find(thisLimit);
    limits[i] = rrv->getVal();
  }
}

void AFitParametricStepFunction::buildPdf() {
  // Build the Pdf
  _thePdf = new RooParametricStepFunction(_name, "ParametricStepFunction PDF", *_x, coefList, limits, (int)nBins.getVal());
}

