/*****************************************************************************
 * Project: BaBar detector at the SLAC PEP-II B-factory
 * Package: AFit
 *    File: $Id: AFitStepFunctionPdf.cc
 * Authors:
 *    A Bevan (a.j.bevan@qmul.ac.uk)
 *
 * Copyright (C) 2008 QMUL
 *****************************************************************************/

// -- CLASS DESCRIPTION [PDF] --
// Implementation of a RooAbsPdf Step function (or veto)
//
#include <math.h>

#include "AFit/AFitStepFunctionPdf.hh"
#ifdef __BABARROOFIT__
#include "RooFitCore/RooAbsReal.hh"
#include "RooFitCore/RooRealVar.hh"
#else
#include "RooAbsReal.h"
#include "RooRealVar.h"
#endif

ClassImp(AFitStepFunctionPdf)

AFitStepFunctionPdf::AFitStepFunctionPdf(const char *name, const char *title,
		       RooAbsReal& _x, RooAbsReal& _limits, RooCategory &_veto) :
  RooAbsPdf(name, title),
  x("x", "Dependent", this, _x),
  limits("limits", "Step Limits", this, _limits),
  veto(_veto, "veto")
{
  cout << ClassName() << ": constructor" << endl; 
}

AFitStepFunctionPdf::AFitStepFunctionPdf(const AFitStepFunctionPdf& other, const char* name) :
  RooAbsPdf(other, name), x("x", this, other.x), limits("limits", this, other.limits),veto(other.veto, "veto")
{
}

Double_t AFitStepFunctionPdf::evaluate() const {
  double fn = 0;
  if(veto=="true") {
    if(!((x < limits.max()) && (x > limits.min())))  fn = 1;
  } 
  else if((x < limits.max()) && (x > limits.min()))  fn = 1;

  return fn;
}

